#
# spec file for package rabbitmq-c
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2012-2015 Remi Collet
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global libname     librabbitmq
%global majsonum    4
Name:           rabbitmq-c
Version:        0.10.0
Release:        3.19
Summary:        Client library for AMQP
License:        MIT
Group:          Development/Libraries/C and C++
URL:            https://github.com/alanxz/rabbitmq-c
Source0:        https://github.com/alanxz/rabbitmq-c/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM https://github.com/alanxz/rabbitmq-c/pull/638 
Patch0:         reproducible.patch
BuildRequires:  cmake > 2.8
BuildRequires:  gcc
BuildRequires:  openssl-devel
# For tools
BuildRequires:  popt-devel
# For man page
BuildRequires:  xmlto
# SECTION test requirements
BuildRequires:  rabbitmq-server
BuildRequires:  rabbitmq-server-plugins
# /SECTION

%description
This is a C-language AMQP client library for use with AMQP servers
speaking protocol versions 0-9-1.

%package -n %{libname}%{majsonum}
Summary:        Client library for AMQP
Group:          Development/Libraries/C and C++

%description -n %{libname}%{majsonum}
This is a C-language AMQP client library for use with AMQP servers
speaking protocol versions 0-9-1.

%package -n %{libname}-devel
Summary:        Header files and development libraries for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname}%{majsonum} = %{version}

%description -n %{libname}-devel
This package contains the header files and development libraries
for %{name}.

%package -n %{name}-tools
Summary:        Example tools built using the librabbitmq package
Group:          Development/Libraries/C and C++

%description -n %{name}-tools
This package contains example tools built using %{name}. It provides:
amqp-consume        Consume messages from a queue on an AMQP server
amqp-declare-queue  Declare a queue on an AMQP server
amqp-delete-queue   Delete a queue from an AMQP server
amqp-get            Get a message from a queue on an AMQP server
amqp-publish        Publish a message on an AMQP server

%prep
%setup -q
%patch0 -p1

%build
# static lib required for tests
%cmake \
  -DBUILD_TOOLS_DOCS:BOOL=ON \
  -DBUILD_STATIC_LIBS:BOOL=ON
%cmake_build

%install
%cmake_install
rm %{buildroot}%{_libdir}/%{libname}.a

%check
# check .pc is usable
grep @ %{buildroot}%{_libdir}/pkgconfig/librabbitmq.pc && exit 1
# upstream tests
#
# https://github.com/alanxz/rabbitmq-c/issues/602
# rabbitmq-server needs to run only for test_basic,
# which can be skipped in case this will bring some
# issues
exit_code=0
echo "### Starting RabbitMQ server .."
pid_file="/home/abuild/rabbitmq/rabbitmq.pid"
export RABBITMQ_PID_FILE=$pid_file
export RABBITMQ_LOG_BASE=/home/abuild/rabbitmq/log
export RABBITMQ_MNESIA_BASE=/home/abuild/rabbitmq/mnesia
%if 0%{?suse_version} <= 1500
export RABBITMQ_SCHEMA_DIR=/home/abuild/rabbitmq/schema
export RABBITMQ_GENERATED_CONFIG_DIR=/home/abuild/rabbitmq/config
%endif
sbin_base=%{_libdir}/rabbitmq/lib/rabbitmq_server-*/sbin
$sbin_base/rabbitmq-server&
sleep 5
$sbin_base/rabbitmqctl await_startup
echo "### Done, running tests"
%ctest || exit_code=1
echo "### Stopping RabbitMQ server .."
$sbin_base/rabbitmqctl stop
# needs to wait: Killing not allowed - living nodes in database.
sleep 5
epmd -kill
echo "### Done"
exit $exit_code

%post -n %{libname}%{majsonum} -p /sbin/ldconfig
%postun -n %{libname}%{majsonum} -p /sbin/ldconfig

%files -n %{libname}%{majsonum}
%doc LICENSE-MIT
%{_libdir}/%{libname}.so.%{majsonum}*

%files -n %{libname}-devel
%doc AUTHORS THANKS TODO *.md examples
%{_libdir}/%{libname}.so
%{_includedir}/amqp*
%{_libdir}/pkgconfig/%{libname}.pc

%files -n %{name}-tools
%{_bindir}/amqp-*
%{_mandir}/man1/amqp-*.1%{?ext_man}
%{_mandir}/man7/librabbitmq-tools.7%{?ext_man}

%changelog
* Tue Dec 22 2020 bwiedemann@suse.com
- Add reproducible.patch to override build date (boo#1047218)
* Thu Dec 17 2020 pgajdos@suse.com
- %%check: use rabbitmqctl await_startup to wait for RabbitMQ
  server start and rabbitmqctl stop for stopping the server
  [bsc#1180096]
* Fri Oct 30 2020 pgajdos@suse.com
- fix tests for SLE15
* Thu Sep  3 2020 pgajdos@suse.com
- do not skip test_basic, try to run rabbitmq-server instead
- deleted patches
  - rabbitmq-c-remove_failing_test-0.9.0.patch (not needed)
* Wed Sep  2 2020 pgajdos@suse.com
- rework the package [jsc#SLE-12262]:
  * run spec-cleaner
  * use cmake macros
  * source package name after github project, library package
    as subpackage
  * update to 0.10.0
  - amqp_ssl_socket_get_context can be used to get the current OpenSSL CTX*
    associated with a connection.
  - openssl: missing OpenSSL config is ignored as an OpenSSL init error (#523)
  - AMQP_DEFAULT_MAX_CHANNELS is now set to 2047 to follow current default channel
    limit in the RabbitMQ broker. (#513)
  - add additional input validation to prevent integer overflow when parsing a
    frame header. This addresses CVE-2019-18609.
* Mon May 28 2018 tuukka.pasanen@ilmi.fi
- Update to version 0.9.0
  * amqp-publish: added support for specifying headers via the -H flag
  * Add support for specifying timeout for amqp_login calls via
  * amqp_set_handshake_timeout
  * Add support for specifying timeouts in RPC-style AMQP methods via
  * amqp_set_rpc_timeout
  * Add define for AMQP_DEFAULT_VHOST
  * Support for SSL SNI
  * Support for OpenSSL v1.1.0
- Changed:
  * rabbitmq-c now requires Windows Vista or better
  * rabbitmq-c enables TCP keep-alive by default on platforms that support it
  * dropped support for compiling rabbitmq-c without threading support
  * OpenSSL is no longer un-intialized automatically by default. OpenSSL can be
    explicitly initialized by calling amqp_initialize_ssl_library and
    uninitialized by calling amqp_uninitialize_ssl_library.
- Fixed:
  * Correct bugs in processing of --url flag in tools (#364).
  * Improve documentation on AMQP_SASL_METHOD_EXTERNAL (#349)
  * Improve support for compiling under mingw-w64
  * Better support for handing SIGPIPE on Linux over SSL (#401)
  * Improve publish performance on Linux by not specifying MSG_MORE on last part
    of message.
  * Fix connection logic where multiple hostnames won't be tried if
    connection to doesn't fail immediately (#430)
- Removed:
  * autotools build system has been removed
  * many duplicate amqps_* examples, they did not add a lot of value
